pub trait Dialect {
// Required methods
fn name(&self) -> &'static str;
fn description(&self) -> &'static str;
}Expand description
Dialects can define new operations, attributes, and types. Each dialect is given an unique namespace that is prefixed.
Dialects can co-exist and can be produced and consumed by different passes.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".